package no.statnett.ecp.edx;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class Measurement {
  private long yyyyMMddHHmm;
  private boolean snd;
  private Set<String> ecpIds = new HashSet<>();
  private Set<String> edxIds = new HashSet<>();
  private List<String> ecpLogLines = new ArrayList<>();
  private List<String> edxLogLines = new ArrayList<>();
  private List<String> expirations = new ArrayList<>();


  public Measurement(long yyyyMMddHHmm, boolean snd) {
    this.yyyyMMddHHmm = yyyyMMddHHmm;
    this.snd = snd;
  }

  public long getTms() {
    return yyyyMMddHHmm;
  }

  public void addEcpId(String ecpId, String logLine) {
    ecpIds.add(ecpId);
    ecpLogLines.add(logLine);
  }

  public void addEdxId(String edxId, String logLine) {
    edxIds.add(edxId);
    edxLogLines.add(logLine);
  }

  public void addExpiration(String expiration) {
    this.expirations.add(expiration);
  }

  public int diff() {
    // If you send messages, you can allow that ECP size is bigger than EDX size
    // If you receive messages, you can allow that EDX size is bigger than ECP size
    if (snd) {
      return ecpIds.size() - edxIds.size(); // Should never be less than 0
    } else {
      return edxIds.size() - ecpIds.size(); // Should never be less than 0
    }
  }

  public int getEcpTraffic() {
    return ecpIds.size();
  }

  public int getEdxTraffic() {
    return edxIds.size();
  }

  public List<String> getEcpLogLines() {
    return ecpLogLines;
  }

  public List<String> getEdxLogLines() {
    return edxLogLines;
  }

  public List<String> getExpirations() {
    return expirations;
  }


}
